@@ -3,7 +3,7 @@ package Tk::More;
 use strict;
 use vars qw($VERSION @ISA);
 
-$VERSION = substr(q$Revision: 2.6 $, 10) . "";
+$VERSION = sprintf("%d.%02d", q$Revision: 5.5 $ =~ /(\d+)\.(\d+)/);
 
 use Tk qw(Ev);
 use Tk::Derived;
@@ -92,11 +92,18 @@ sub Populate {
 	}
     }
 
+    # This was formerly possible, but is now invalid:
+    delete $args->{-font} if !defined $args->{-font};
+
     $cw->Delegates('DEFAULT'   => $t,
 		   'Search'    => 'SELF',
 		   'ShowMatch' => 'SELF',
+		   'Load'      => 'SELF',
+		   'AddQuitBindings' => 'SELF',
 		  );
 
+    $cw->{DIRECTION} = "Next";
+
     $cw->ConfigSpecs(
 		-insertofftime => [$t, qw(insertOffTime OffTime         0)], # no blinking
 		-insertwidth   => [$t, qw(insertWidth   InsertWidth     0)], # invisible
@@ -104,6 +111,8 @@ sub Populate {
 		-pady          => [$t, qw(padY          Pad            5p)],
 		-searchcase    => ['PASSIVE', 'searchCase', 'SearchCase', 1],
 		-helpcommand   => ['CALLBACK', undef, undef, undef],
+		-background    => ['PASSIVE'],# XXX ignore -background, so optionAdd works.... still decide
+		-font	       => [$t, 'fixedFont', 'FixedFont', 'Courier 10'],
 		'DEFAULT'      => [$t]
 		);
 
@@ -186,9 +195,15 @@ sub ShowMatch {
 # Load copied from TextUndo (xxx yy marks changes)
 sub Load
 {
- my ($text,$file) = @_;
+ my ($text,$file,%args) = @_;
+ my $encoding = delete $args{-encoding};
+ die "Unhandled arguments: " . join(" ", %args) if %args;
  if (open(FILE,"<$file"))
   {
+   if ($encoding)
+    {
+     binmode FILE, ":encoding($encoding)";
+    }
    $text->MainWindow->Busy;
    $text->SUPER::delete('1.0','end');
    #yy delete $text->{UNDO};
@@ -285,6 +300,11 @@ sub scroll {
     Tk->break;
 }
 
+sub AddQuitBindings {
+    my($more) = @_;
+    $more->bind("<q>" => sub { $more->toplevel->destroy });
+    $more->bind("<Control-q>" => sub { $more->toplevel->destroy });
+}
 
 #package Tk::More::Status;
 #
@@ -316,27 +336,27 @@ additional status/command line is added at the bottom.
 
 =over 4
 
-=item Key-g
+=item Key-g or Home
 
 goto beginning of file
 
-=item Key-G
+=item Key-G or End
 
 goto end of file
 
-=item Key-f
+=item Key-f or Next
 
 forward screen
 
-=item Key-b
+=item Key-b or Prior
 
 backward screen
 
-=item Key-k
+=item Key-k or Up
 
 up one line
 
-=item Key-j
+=item Key-j or Down
 
 down one line
 
@@ -364,6 +384,64 @@ up half screen
 
 down half screen
 
+=item Key-Return
+
+down one line
+
+=item Key-h
+
+invoke help window
+
+=back
+
+=head1 OPTIONS
+
+=over
+
+=item Name:     B<fixedFont>
+
+=item Class:    B<FixedFont>
+
+=item Switch:   B<-font>
+
+Set the font of the viewer widget. This is by default a fixed font.
+
+=item Name:     B<searchCase>
+
+=item Class:    B<SearchCase>
+
+=item Switch:   B<-searchcase>
+
+Set if searching should be done case-insensitive. Defaults to true.
+
+=item Switch:   B<-helpcommand>
+
+Sets the command for the "h" (help) key.
+
+=back
+
+=head1 METHODS
+
+=over
+
+=item Load($file, %args)
+
+Load I<$file> into the widget. I<%args> may be one of the following
+
+=over
+
+=item -encoding => I<$encoding>
+
+Assume the encoding of the file to be I<$encoding>. If none is given,
+then assume no encoding (which is equivalent to iso-8859-1).
+
+=back
+
+=item AddQuitBindings
+
+Convenience method to add the bindinds Key-q and Control-Key-q to
+close the Toplevel window containing this More widget.
+
 =back
 
 =head1 BUGS
@@ -380,13 +458,13 @@ me most (high to low priority):
 
 =head1 SEE ALSO
 
-L<Tk::ROText|Tk::ROText>, more(1), less(1)
+L<Tk::ROText|Tk::ROText>, L<more(1)>, L<tkmore>, L<less(1)>
 
 =head1 AUTHOR
 
 Achim Bohnet <F<ach@mpe.mpg.de>>
 
-Currently maintained by Slaven Rezic <F<slaven.rezic@berlin.de>>.
+Currently maintained by Slaven Rezic <F<slaven@rezic.de>>.
 
 Copyright (c) 1997-1998 Achim Bohnet. All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same
